==> abxy-1.1.2.tar.gz: abxy-1.1.2/README.md <==
# Welcome to Abxy!
Abxy is a third party library for the package named [inkster](https://pypi.org/project/inkster/). Abxy is a package with random interpreters such as ChatPreter the chatbot interpreter.

## Installation

To install abxy just run this in a command prompt:

```bash
pip install abxy
```

## Getting Started

If you would like to use abxy just do this:

Abxy's interpreters starts up from `from (some import) import (some import)`.

Here is a example of running a interpreter:
```python
from abxy.interpreters import chatpreter
```
As soon as you run your file it will run the interpreter right away!

If you would like to see all interpreters available just do this in your file:
```python
from abxy import help
```
And once you run the file it should print out all interpreters available in your console!

## Links & Contacts

- Discord Server: `https://discord.gg/HUFtMsz`

## License

Copyright 2020 AbxyPlayz

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

==> abxy-1.2.2.tar.gz: abxy-1.2.2/README.md <==
# Welcome to Abxy!
Abxy is a third party library for the package named [inkster](https://pypi.org/project/inkster/). Abxy is a package with random interpreters such as ChatPreter the chatbot interpreter.

## Installation

To install abxy just run this in a command prompt:

```bash
pip install abxy
```

## Getting Started

If you would like to use abxy just do this:

Abxy's interpreters starts up from `from (some import) import (some import)`.

Here is a example of running a interpreter:
```python
from abxy import chatpreter
```
As soon as you run your file it will run the interpreter right away!

If you would like to see all interpreters available just do this in your file:
```python
from abxy import help
```
And once you run the file it should print out all interpreters available in your console!

## Links & Contacts

- Discord Server: `https://discord.gg/HUFtMsz`

## License

Copyright 2020 AbxyPlayz

Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
